@@ -31,7 +31,9 @@
    main changes compared to DeaDBeeF:
      removed deadbeef functions and structures
      added public callback api
+     added mingw support
      fixed some gcc warnings
+
 */
 
 #if HAVE_CONFIG_H
@@ -45,6 +47,15 @@
 #include <math.h>
 #include "ffap.h"
 
+
+#if defined(_WIN32) && ! defined(_MSC_VER)
+#include <malloc.h>
+int posix_memalign (void **memptr, size_t alignment, size_t size) {
+    *memptr = __mingw_aligned_malloc (size, alignment);
+    return *memptr ? 0 : -1;
+}
+#endif
+
 #ifdef TARGET_ANDROID
 int posix_memalign (void **memptr, size_t alignment, size_t size) {
     *memptr = memalign (alignment, size);
@@ -65,19 +76,6 @@ int posix_memalign (void **memptr, size_t alignment, size_t size) {
 #define min(x,y) ((x)<(y)?(x):(y))
 #define max(x,y) ((x)>(y)?(x):(y))
 
-static inline unsigned int bytestream_get_buffer(const uint8_t **b, uint8_t *dst, unsigned int size)
-{
-    memcpy(dst, *b, size);
-    (*b) += size;
-    return size;
-}
-
-static inline void bytestream_put_buffer(uint8_t **b, const uint8_t *src, unsigned int size)
-{
-    memcpy(*b, src, size);
-    (*b) += size;
-}
-
 static inline uint8_t bytestream_get_byte (const uint8_t **ptr) {
     uint8_t v = *(*ptr);
     (*ptr)++;
@@ -371,7 +369,6 @@ ape_read_header (FFap_decoder *decoder)
 //ape_read_header(DB_FILE *fp, APEContext *ape)
 {
     uint32_t i;
-    int total_blocks;
     APEContext *ape = decoder->ape_ctx;
 
     /* TODO: Skip any leading junk such as id3v2 tags */
@@ -579,8 +576,6 @@ ape_read_header (FFap_decoder *decoder)
     fprintf (stderr, "ape: Decoding file - v%d.%02d, compression level %d\n", ape->fileversion / 1000, (ape->fileversion % 1000) / 10, ape->compressiontype);
 #endif
 
-    total_blocks = (ape->totalframes == 0) ? 0 : ((ape->totalframes - 1) * ape->blocksperframe) + ape->finalframeblocks;
-
     return 0;
 }
 
@@ -666,10 +661,15 @@ ape_free_ctx (APEContext *ape_ctx) {
     }
     for (i = 0; i < APE_FILTER_LEVELS; i++) {
         if (ape_ctx->filterbuf[i]) {
+#if defined(_WIN32) && ! defined(_MSC_VER)
+            __mingw_aligned_free(ape_ctx->filterbuf[i]);
+#else
             free (ape_ctx->filterbuf[i]);
+#endif
             ape_ctx->filterbuf[i] = NULL;
         }
     }
+    free(ape_ctx);
 }
 
 void ffap_free (FFap_decoder *decoder)
@@ -684,7 +684,7 @@ int ffap_init(FFap_decoder *decoder)
             || !decoder->getlength || !decoder->client_data)
         return -1;
 
-    memset(decoder->ape_ctx, 0, sizeof(decoder->ape_ctx));
+    memset(decoder->ape_ctx, 0, sizeof(APEContext));
 
     /*int skip = deadbeef->junk_get_leading_size (info->fp);
     if (skip > 0) {
@@ -790,12 +790,12 @@ static inline void range_dec_normalize(APEContext * ctx)
  * @param tot_f is the total frequency or (code_value)1<<shift
  * @return the culmulative frequency
  */
-static inline int range_decode_culfreq(APEContext * ctx, int tot_f)
+/*static inline int range_decode_culfreq(APEContext * ctx, int tot_f)
 {
     range_dec_normalize(ctx);
     ctx->rc.help = ctx->rc.range / tot_f;
     return ctx->rc.low / ctx->rc.help;
-}
+}*/
 
 /**
  * Decode value with given size in bits
